==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/97/97fda35fdde71f726f56225e5a7d0e78.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/causebuzz-grapejs-suite/config.json */
class __TwigTemplate_bb2df5e625945f0bf2d3c428cd3f8703 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "{
  \"name\": \"Cause.Buzz Professional GrapeJS Suite\",
  \"author\": \"Cause.Buzz Team\",
  \"authorUrl\": \"https://cause.buzz\",
  \"version\": \"2.1.1\",
  \"description\": \"Complete Mautic theme suite with GrapeJS integration for emails, landing pages and forms. Features: Modern GrapeJS Integration, Drag & Drop Visual Builder, 5 Professional Templates, 20+ Reusable Components, Mobile-First Responsive Design, DSGVO-compliant EU hosting badges, Cause.Buzz brand consistency, Cross-client compatibility, Dark mode support, Accessibility optimized.\",
  \"demo\": \"https://demo.cause.buzz/email-builder\",
  \"documentation\": \"https://cause.buzz/docs/email-templates\",
  \"onlyForBC\": false,
  \"builder\": [
    \"legacy\",
    \"grapesjsbuilder\"
  ],
  \"features\": [
    \"grapesjsbuilder\"
  ],
  \"slots\": [
    {
      \"name\": \"grapesjsbuilder\",
      \"default\": true
    },
    {
      \"name\": \"legacy\"
    }
  ]
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/causebuzz-grapejs-suite/config.json";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/causebuzz-grapejs-suite/config.json", "/var/www/html/mauticGIT-Test/themes/causebuzz-grapejs-suite/config.json");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/97/97fda35fdde71f726f56225e5a7d0e78.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/causebuzz-grapejs-suite/config.json */
class __TwigTemplate_bb2df5e625945f0bf2d3c428cd3f8703 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "{
  \"name\": \"Cause.Buzz Professional GrapeJS Suite\",
  \"author\": \"Cause.Buzz Team\",
  \"authorUrl\": \"https://cause.buzz\",
  \"version\": \"2.1.1\",
  \"description\": \"Complete Mautic theme suite with GrapeJS integration for emails, landing pages and forms. Features: Modern GrapeJS Integration, Drag & Drop Visual Builder, 5 Professional Templates, 20+ Reusable Components, Mobile-First Responsive Design, DSGVO-compliant EU hosting badges, Cause.Buzz brand consistency, Cross-client compatibility, Dark mode support, Accessibility optimized.\",
  \"demo\": \"https://demo.cause.buzz/email-builder\",
  \"documentation\": \"https://cause.buzz/docs/email-templates\",
  \"onlyForBC\": false,
  \"builder\": [
    \"legacy\",
    \"grapesjsbuilder\"
  ],
  \"features\": [
    \"grapesjsbuilder\"
  ],
  \"slots\": [
    {
      \"name\": \"grapesjsbuilder\",
      \"default\": true
    },
    {
      \"name\": \"legacy\"
    }
  ]
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/causebuzz-grapejs-suite/config.json";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/causebuzz-grapejs-suite/config.json", "/var/www/html/production-demo/themes/causebuzz-grapejs-suite/config.json");
    }
}
